@@ -34,7 +34,7 @@ class DynamoDB:
         """
         return self.ddb_client
 
-    def put_ddb_object(self, table_name, item_dict):
+    def put_ddb_object(self, table_name, item_dict, debug=True):
         """
             Puts an item into the DynamoDB table
         ​
@@ -45,11 +45,12 @@ class DynamoDB:
 
         table = self.ddb_client.Table(table_name)
         response = table.put_item(Item=item_dict)
-        print(f"Successfully uploaded item to table {table_name}")
+        if debug:
+            print(f"Successfully uploaded item to table {table_name}")
 
         return response
 
-    def put_ddb_df_pyspark(self, table_name, pyspark_df):
+    def put_ddb_df_pyspark(self, table_name, pyspark_df, debug=True):
         """
         This function takes a PySpark dataframe, transforms it into a Pandas dataframe and inserts it to the specified dynamodb table object.
 
@@ -68,13 +69,14 @@ class DynamoDB:
             for i, record in enumerate(pandas_df.to_dict("records")):
                 bw.put_item(Item=record)
 
-        print(
-            "Successfully inserted {} rows into DynamoDB Table: {}".format(
-                pyspark_df.count(), table_name
+        if debug:
+            print(
+                "Successfully inserted {} rows into DynamoDB Table: {}".format(
+                    pyspark_df.count(), table_name
+                )
             )
-        )
 
-    def put_ddb_df_pandas(self, table_name, pd_df):
+    def put_ddb_df_pandas(self, table_name, pd_df, debug=True):
         """
         This function takes a Pandas dataframe
 
@@ -88,13 +90,14 @@ class DynamoDB:
             for i, record in enumerate(pd_df.to_dict("records")):
                 bw.put_item(Item=record)
 
-        print(
-            "Successfully inserted {} rows into DynamoDB Table: {}".format(
-                pd_df.shape[0], table_name
+        if debug:
+            print(
+                "Successfully inserted {} rows into DynamoDB Table: {}".format(
+                    pd_df.shape[0], table_name
+                )
             )
-        )
 
-    def get_ddb_object(self, table_name, key_name, search_key):
+    def get_ddb_object(self, table_name, key_name, search_key, debug=True):
         """
             Returns an item from the table based on the specified key and item
         ​
@@ -105,6 +108,7 @@ class DynamoDB:
         """
         table = self.ddb_client.Table(table_name)
         response = table.get_item(Key={key_name: search_key})
-        print(f"Successfully retrieved {search_key} from {table_name}")
+        if debug:
+            print(f"Successfully retrieved {search_key} from {table_name}")
 
         return response
